function [rfit,n1,n2,k1,k2]=disp_model_wrap_ac(coef,p)
% disp_model_wrap_ac: wrapper for dispersion model.
%    lsqcurvefit requires all coefficients in one vector or rectangular
%    matrix. This function separates the vector back into oscillator
%    parameters to more readily input into the actual dispersion model.
%
% inputs: p - predictors (frequency list, omega)
%         r - measured reflectance
%
% returns: rfit - reflectance fit
%          n1,n2,k1,k2 - optical constants

N=(length(coef)-4)./5;
if ~isint(N), 
  error('disp_model_wrap_oblique: bad length for coefficient list!');
end

nu=coef(1:N);
gamm=coef(N+(1:N));
Sk=coef(2.*N+(1:N));
phi=coef(3.*N+(1:N));
theta=coef(4.*N+(1:N));
epsilxx=coef(5.*N+1);
epsilxy=coef(5.*N+2);
epsilyy=coef(5.*N+3);
epsilzz=coef(5.*N+4);

[n1,n2,k1,k2,e_xx,e_xy,e_yy,e_zz]=dispersion_model_ac(nu,gamm,Sk,phi,theta,epsilxx,epsilxy,epsilyy,epsilzz,p);
rfit=fresnel_ac(e_xx,e_xy,e_yy,e_zz);