function [n1,n2,k1,k2,e_xx,e_xy,e_yy,e_zz]=dispersion_model_ac(nu,gamm,Sk,phi,theta,epsilxx,epsilxy,epsilyy,epsilzz,p)
% dispersion_model: Mayerhofer et al.
%
% inputs: p - predictors (frequency list, omega)
%         gamm - damping parameter
%         Sk - bandwidth parameter
%         epsil - bulk dielectric constants
%
% returns: n1,n2,k1,k2 - optical constants
%          e_xx,e_xy,e_yy,e_zz - dielectric tensor

v=p(:,1); omega=p(:,2);

% make nu, Sk, gamm, phi, theta be 1xN 
nu=nu(:)'; Sk=Sk(:)'; gamm=gamm(:)'; phi=phi(:)'; theta=theta(:)';

v=repmat(v,1,length(nu));
omega=repmat(omega,1,length(nu));
phi=repmat(phi,length(v),1);
theta=repmat(theta,length(v),1);
nu=repmat(nu,length(v),1);
Sk=repmat(Sk,length(v),1);
gamm=repmat(gamm,length(v),1);

%calculate dielectric tensor
uxx=((sind(theta)).^2).*((cosd(phi)).^2);
uxy=((sind(theta)).^2).*(cosd(phi)).*(sind(phi));
uyy=((sind(theta)).^2).*((sind(phi)).^2);
uzz=(cosd(theta)).^2;

denom=(nu.^2-v.^2)-(sqrt(-1))*gamm.*v;

L_k_xx=uxx.*Sk./denom; 
L_k_xy=uxy.*Sk./denom;
L_k_yy=uyy.*Sk./denom;
L_k_zz=uzz.*Sk./denom;

e_11=epsilxx + sum(L_k_xx,2);  
e_12=epsilxy + sum(L_k_xy,2);
e_22=epsilyy + sum(L_k_yy,2);
e_33=epsilzz + sum(L_k_zz,2);

%rotate dielectric tensor to match coordinate system
e_xx=e_11.*(cosd(omega(:,1))).^2+e_22.*(sind(omega(:,1))).^2+2*e_12.*cosd(omega(:,1)).*sind(omega(:,1));
e_xy=e_12.*(cosd(omega(:,1))).^2-e_12.*(sind(omega(:,1))).^2+(e_22-e_11).*cosd(omega(:,1)).*sind(omega(:,1));
e_yy=e_22.*(cosd(omega(:,1))).^2+e_11.*(sind(omega(:,1))).^2-2*e_12.*cosd(omega(:,1)).*sind(omega(:,1));
e_zz=e_33;

%calculate optical constants
m1sq=zeros(length(v),1); m2sq=zeros(length(v),1);
m1sq(1)=(e_xx(1)+e_yy(1))./2 + sqrt(((e_xx(1)-e_yy(1)).^2)/4 + e_xy(1).^2);
m2sq(1)=(e_xx(1)+e_yy(1))./2 - sqrt(((e_xx(1)-e_yy(1)).^2)/4 + e_xy(1).^2);

%enforce continuity
for i=2:1:length(v)
    sl1=(e_xx(i)+e_yy(i))./2 + sqrt(((e_xx(i)-e_yy(i)).^2)/4 + e_xy(i).^2);
    sl2=(e_xx(i)+e_yy(i))./2 - sqrt(((e_xx(i)-e_yy(i)).^2)/4 + e_xy(i).^2);
    if (abs(sl1-m1sq(i-1)))<(abs(sl1-m2sq(i-1)))
        m1sq(i)=sl1; m2sq(i)=sl2;
    else
        m1sq(i)=sl2; m2sq(i)=sl1;
    end
end

m1=sqrt(m1sq); m2=sqrt(m2sq);
n1=real(m1); k1=imag(m1);
n2=real(m2); k2=imag(m2);

