function [n,k]=dispersion_model(nu,gamm,fourpr,epsil,v)
% dispersion_model: Spitzer and Kleinman dispersion model
% v: frequency list
% gamm: damping parameter
% fourpr: bandwidth parameter
% epsil: bulk dialectric constant

% make v be Mx1
v=v(:);
% make nu, fourpr, gamm be 1xN 
nu=nu(:)'; fourpr=fourpr(:)'; gamm=gamm(:)'; 

%change units
fourpr=fourpr./(nu.^2);  gamm=gamm./nu;

v=repmat(v,1,length(nu));
nu=repmat(nu,length(v),1);
fourpr=repmat(fourpr,length(v),1);
gamm=repmat(gamm,length(v),1);

a=nu.^2-v.^2;

denom=a.^2+(nu.*gamm.*v).^2;
alpha=fourpr.*nu.^2.*a./denom;
bet=(fourpr./2).*nu.^2.*gamm.*nu.*v./denom;
theta=epsil+sum(alpha,2);
phi=sum(bet,2);
a2=sqrt(theta.^2+4.*phi.^2);
n=sqrt((theta+a2)./2);
k=phi./n;

