% Outputs optical constants for minerals with orthogonal 
% symmetry and the b-axis of monoclinic minerals 
clear all;

% read data
[v,r]=textread('./Thu Sep 22 12-46-49 2011 (GMT-04-00)Orthoclase_b.CSV','%f %f');

% Clip reflectance data to desired wavenumber range.
lo_wn=400; %set lower bound
up_wn=2000; %set upper bound

r=r(find(v>lo_wn)); v=v(find(v>lo_wn));
r=r(find(v<up_wn)); v=v(find(v<up_wn));

% convert to reflectance from % reflectance  
r=0.01*(r);

% Read in parameter estimates, upper and lower bounds from 
% file param_values.txt

%get number of oscillators
fid=fopen('param_values_b.txt');
ncols=length(textscan(fid,'','HeaderLines',1,'Delimiter',','));
disp(['number of oscillators: ', num2str(ncols)]);
fclose(fid);

%read paramter input file
parameter_file = fopen('param_values_b.txt');
textformat=repmat('%f',1,ncols);
nu=textscan(parameter_file,textformat,'HeaderLines',2,'Delimiter',',');
gamm = textscan(parameter_file,textformat,'HeaderLines',1,'Delimiter',',');
Sk = textscan(parameter_file,textformat,'HeaderLines',1,'Delimiter',',');
textformat='%f';
epsil = textscan(parameter_file,textformat,'HeaderLines',1); 
%read in lower bounds
textformat=repmat('%f',1,ncols);
lb_nu=textscan(parameter_file,textformat,'HeaderLines',2,'Delimiter',',');
lb_gamm = textscan(parameter_file,textformat,'HeaderLines',1,'Delimiter',',');
lb_Sk = textscan(parameter_file,textformat,'HeaderLines',1,'Delimiter',',');
textformat='%f';
lb_epsil = textscan(parameter_file,textformat,'HeaderLines',1); 
%read in upper bounds
textformat=repmat('%f',1,ncols);
ub_nu=textscan(parameter_file,textformat,'HeaderLines',2,'Delimiter',',');
ub_gamm = textscan(parameter_file,textformat,'HeaderLines',1,'Delimiter',',');
ub_Sk = textscan(parameter_file,textformat,'HeaderLines',1,'Delimiter',',');
textformat='%f';
ub_epsil = textscan(parameter_file,textformat,'HeaderLines',1); 
fclose(parameter_file);

% Concatenate together guesses to make coefficient vector. lsqcurvefit
% requires the model parameters to be in one vector or rectangular array.

coefg=cell2mat([nu,gamm,Sk,epsil]);

% Concatenate together upper and lower bounds.
lb=cell2mat([lb_nu,lb_gamm,lb_Sk,lb_epsil]);
ub=cell2mat([ub_nu,ub_gamm,ub_Sk,ub_epsil]);

% Allows the user to see if there is a mis-match between the number of
% parameters and the number of bounds
if(or(length(coefg)~=length(lb),length(coefg)~=length(ub)))
    display('Number of coefficients do not match number of bounds!');
end
disp(['number of coefficients: ', num2str(length(coefg))]); 
disp(['number of lower bounds: ', num2str(length(lb))]); 
disp(['number of upper bounds: ', num2str(length(ub))]);

% do nonlinear inversion
options=optimset('Display','iter','MaxIter',10000);
[coeff,resnorm,res,exitflag,output,lambda,J]=lsqcurvefit(@disp_model_wrap_sbu,coefg,v,r,lb,ub,options);

% run forward model to produce guess and fitted spectra emg and emf
rg=disp_model_wrap_sbu(coefg,v);
[rf,n,k]=disp_model_wrap_sbu(coeff,v);

opconst=cat(2,v,n,k);

% write final oscillator parameters to file 'new_param_values.txt')
fid = fopen('param_values_b.txt','r');
i = 1;
tline = fgetl(fid);
temp_params{i} = tline;
while ischar(tline)
    i = i+1;
    tline = fgetl(fid);
    temp_params{i} = tline;
end
fclose(fid);
textformat=(repmat('%f,',1,ncols)); textformat=textformat(1:length(textformat)-1);
temp_params{3}=sprintf(textformat,coeff(1:ncols));
temp_params{5}=sprintf(textformat,coeff(ncols+(1:ncols)));
temp_params{7}=sprintf(textformat,coeff(2.*ncols+(1:ncols)));
temp_params{9}=sprintf('%f',coeff(3.*ncols+1));

fid = fopen('new_param_values_b.txt', 'w');
fprintf(fid, '%s\n', temp_params{:});
fclose(fid);

%save results
dlmwrite('optical_constants_b.txt', opconst, 'delimiter', '\t', 'precision', 6);
dlmwrite('disp_param_b.txt',coeff','delimiter','\t','precision',6);

figure(1); clf;
plot(v,r,v,rf,'LineWidth',3.0);
set(gca,'XDir','reverse','FontSize',14)
legend('observed E || b','modeled','FontSize',14)
ylabel('Reflectance','FontSize',14);
xlabel('Wavenumber (cm^{-1})','FontSize',14);

figure(2); clf;
plot(v,r-rf,'-k','LineWidth',3.0);
set(gca,'XDir','reverse','FontSize',14)

figure(3); clf;
subplot(2,1,1); plot(v,n,'LineWidth',3.0,'Color',[0 0 0]);
set(gca,'XDir','reverse','FontSize',14)
ylabel('n','FontSize',14);
xlabel('Wavenumber (cm^{-1})','FontSize',14);
subplot(2,1,2); plot(v,k,'LineWidth',3.0,'Color',[0 0 0]);
set(gca,'XDir','reverse','FontSize',14)
ylabel('k','FontSize',14);
xlabel('Wavenumber (cm^{-1})','FontSize',14);
